@@ -1,4 +1,4 @@
-# This code is part of Perl distribution Log-Report-Lexicon version 1.15.
+# This code is part of Perl distribution Log-Report-Lexicon version 1.16.
 # The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
@@ -8,13 +8,9 @@
 # the same terms as the Perl 5 programming language system itself.
 # SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
 
-#oodist: *** DO NOT USE THIS VERSION FOR PRODUCTION ***
-#oodist: This file contains OODoc-style documentation which will get stripped
-#oodist: during its release in the distribution.  You can use this file for
-#oodist: testing, however the code of this development version may be broken!
 
 package Log::Report::Extract::PerlPPI;{
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 }
 
 use base 'Log::Report::Extract';
@@ -23,6 +19,7 @@ use warnings;
 use strict;
 
 use Log::Report 'log-report-lexicon';
+
 use PPI    ();
 use Encode qw/decode/;
 
@@ -56,11 +53,11 @@ sub process($@)
 
 	my @childs = $doc->schildren;
 	if(@childs==1 && ref $childs[0] eq 'PPI::Statement')
-	{	info __x"no Perl in file {filename}", filename => $fn;
+	{	info __x"no Perl in file {filename}.", filename => $fn;
 		return 0;
 	}
 
-	info __x"processing file {fn} in {charset}", fn=> $fn, charset => $charset;
+	info __x"processing file {fn} in {charset}.", fn=> $fn, charset => $charset;
 	my ($pkg, $include, $domain, $msgs_found) = ('main', 0, undef, 0);
 
 NODE:
@@ -107,7 +104,7 @@ NODE:
 			my $node = $_[1];
 			my $word = $node->content;
 			if($word =~ $quote_mistake)
-			{	warning __x"use double quotes not single, in {string} on {file} line {line}",
+			{	warning __x"use double quotes not single, in {string} on {file} line {line}.",
 					string => $word, fn => $fn, line => $node->location->[0];
 				return 0;
 			}
@@ -129,7 +126,7 @@ NODE:
 
 			my $line = $node->location->[0];
 			unless($domain)
-			{	mistake __x"no text-domain for translatable at {fn} line {line}", fn => $fn, line => $line;
+			{	mistake __x"no text-domain for translatable at {fn} line {line}.", fn => $fn, line => $line;
 				return 0;
 			}
 
@@ -172,14 +169,13 @@ sub _get($$$$)
 		{	last if $sep !~ m/^ (?: | \=\> | [,;:] ) $/x;
 			$msgid = $first->string;
 
-			if(  $first->isa("PPI::Token::Quote::Double")
-			|| $first->isa("PPI::Token::Quote::Interpolate"))
+			if(  $first->isa("PPI::Token::Quote::Double") || $first->isa("PPI::Token::Quote::Interpolate"))
 			{	$first->string !~ m/(?<!\\)(\$\w+)/
-					or mistake __x"do not interpolate in msgid (found '{var}' in line {line})", var => $1, line => $line;
+					or mistake __x"do not interpolate in msgid (found '{var}' in line {line}).", var => $1, line => $line;
 
 				# content string is uninterpreted, warnings to screen
 				$msgid = eval "qq{$msgid}";
-				error __x "string is incorrect at line {line}: {error}", line => $line, error => $@ if $@;
+				error __x "string is incorrect at line {line}: {error}.", line => $line, error => $@ if $@;
 			}
 		}
 		elsif($first->isa('PPI::Token::Word'))
@@ -189,7 +185,7 @@ sub _get($$$$)
 		else { last }
 
 		$split || $msgid !~ s/(?<!\\)\n$//
-			or mistake __x "new-line is added automatically (found in line {line})", line => $line;
+			or mistake __x "new-line is added automatically (found in line {line}).", line => $line;
 
 		push @msgids, $msgid;
 		last if $nr_msgids==@msgids || !$sep;
@@ -200,7 +196,7 @@ sub _get($$$$)
 	my $next = $first->snext_sibling;
 
 	!$has_count || $next
-		or error __x"count missing in {function} in line {line}", function => $function, line => $line;
+		or error __x"count missing in {function} in line {line}.", function => $function, line => $line;
 
 	@msgids;
 }
