@@ -1,5 +1,5 @@
-# This code is part of Perl distribution Log-Report-Lexicon version 1.14.
-# The POD got stripped from this file by OODoc version 3.04.
+# This code is part of Perl distribution Log-Report-Lexicon version 1.16.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
 # This software is copyright (c) 2007-2025 by Mark Overmeer.
@@ -8,13 +8,9 @@
 # the same terms as the Perl 5 programming language system itself.
 # SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
 
-#oodist: *** DO NOT USE THIS VERSION FOR PRODUCTION ***
-#oodist: This file contains OODoc-style documentation which will get stripped
-#oodist: during its release in the distribution.  You can use this file for
-#oodist: testing, however the code of this development version may be broken!
 
 package Log::Report::Lexicon::POTcompact;{
-our $VERSION = '1.14';
+our $VERSION = '1.16';
 }
 
 use base 'Log::Report::Lexicon::Table';
@@ -22,7 +18,7 @@ use base 'Log::Report::Lexicon::Table';
 use warnings;
 use strict;
 
-use Log::Report        'log-report-lexicon';
+use Log::Report        'log-report-lexicon', import => [ qw/__x error fault trace warning/ ];
 use Log::Report::Util  qw/escape_chars unescape_chars/;
 
 use Encode             qw/find_encoding/;
@@ -60,13 +56,13 @@ sub read($@)
 	my $add = sub {
 		unless($charset)
 		{	$msgid eq ''
-				or error __x"header not found for charset in {fn}", fn => $fn;
+				or error __x"header not found for charset in {fn}.", fn => $fn;
 
 			$charset = $msgstr[0] =~ m/^content-type:.*?charset=["']?([\w-]+)/mi ? $1
-			  : error __x"cannot detect charset in {fn}", fn => $fn;
+			  : error __x"cannot detect charset in {fn}.", fn => $fn;
 
 			my $enc = find_encoding($charset)
-				or error __x"unsupported charset {charset} in {fn}", charset => $charset, fn => $fn;
+				or error __x"unsupported charset {charset} in {fn}.", charset => $charset, fn => $fn;
 
 			trace "auto-detected charset $charset for $fn";
 			binmode $fh, ":encoding($charset):crlf";
@@ -109,7 +105,7 @@ sub read($@)
 	$add->() if @msgstr;   # don't forget the last
 
 	close $fh
-		or failure __x"failed reading from file {fn}", fn => $fn;
+		or fault __x"failed reading from file {fn}", fn => $fn;
 
 	$self->{origcharset} = $charset;
 	$self->{filename}    = $fn;
@@ -153,7 +149,7 @@ sub msgstr($;$$)
 
 sub _unescape($$)
 {	unless( $_[0] =~ m/^\s*\"(.*)\"\s*$/ )
-	{	warning __x"string '{text}' not between quotes at {location}", text => $_[0], location => $_[1];
+	{	warning __x"string '{text}' not between quotes at {location}.", text => $_[0], location => $_[1];
 		return $_[0];
 	}
 	unescape_chars $1;
