@@ -1,4 +1,4 @@
-# This code is part of Perl distribution Log-Report-Lexicon version 1.15.
+# This code is part of Perl distribution Log-Report-Lexicon version 1.16.
 # The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
@@ -8,20 +8,16 @@
 # the same terms as the Perl 5 programming language system itself.
 # SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
 
-#oodist: *** DO NOT USE THIS VERSION FOR PRODUCTION ***
-#oodist: This file contains OODoc-style documentation which will get stripped
-#oodist: during its release in the distribution.  You can use this file for
-#oodist: testing, however the code of this development version may be broken!
 
 package Log::Report::Lexicon::Table;{
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 }
 
 
 use warnings;
 use strict;
 
-use Log::Report 'log-report-lexicon';
+use Log::Report 'log-report-lexicon', import => [ qw/__x error panic/ ];
 
 #--------------------
 
@@ -32,21 +28,21 @@ sub init($) { $_[0] }
 
 #--------------------
 
-sub msgid($;$)   {panic "not implemented"}
-sub msgstr($;$$) {panic "not implemented"}
+sub msgid($;$)   { panic "not implemented" }
+sub msgstr($;$$) { panic "not implemented" }
 
 #--------------------
 
-sub add($)      {panic "not implemented"}
+sub add($)       { panic "not implemented" }
 
 
-sub translations(;$) {panic "not implemented"}
+sub translations(;$) { panic "not implemented" }
 
 
 sub pluralIndex($)
 {	my ($self, $count) = @_;
 	my $algo = $self->{algo}
-		or error __x"there is no Plural-Forms field in the header, but needed";
+		or error __x"there is no Plural-Forms field in the header, but needed.";
 
 	$algo->($count);
 }
@@ -59,7 +55,7 @@ sub setupPluralAlgorithm()
 	my $alg   = $forms =~ m/plural\=([n%!=><\s\d|&?:()]+)/ ? $1 : "n!=1";
 	$alg =~ s/\bn\b/(\$_[0])/g;
 	my $code  = eval "sub(\$) {$alg}";
-	$@ and error __x"invalid plural-form algorithm '{alg}'", alg => $alg;
+	$@ and error __x"invalid plural-form algorithm '{alg}'.", alg => $alg;
 	$self->{algo}     = $code;
 
 	$self->{nplurals} = $forms =~ m/\bnplurals\=(\d+)/ ? $1 : 2;
