@@ -1,4 +1,4 @@
-# This code is part of Perl distribution Log-Report-Lexicon version 1.15.
+# This code is part of Perl distribution Log-Report-Lexicon version 1.16.
 # The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
@@ -8,20 +8,16 @@
 # the same terms as the Perl 5 programming language system itself.
 # SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
 
-#oodist: *** DO NOT USE THIS VERSION FOR PRODUCTION ***
-#oodist: This file contains OODoc-style documentation which will get stripped
-#oodist: during its release in the distribution.  You can use this file for
-#oodist: testing, however the code of this development version may be broken!
 
 package Log::Report::Translator::Context;{
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 }
 
 
 use warnings;
 use strict;
 
-use Log::Report 'log-report-lexicon';
+use Log::Report 'log-report-lexicon', import => [ qw/__x error warning/ ];
 
 #--------------------
 
